/**
 * A user script for userChrome.js extension.
 * @name PeCaListHelper
 * @description リンクを中/右クリックで専用プレイヤー/ブラウザで開く。
 * @compatibility Firefox 2.0
 * @author PeerSkin
 * @lastupdated 2007.6.16
 * @permalink http://peercast-theme.seesaa.net/
 * ------------------------------------------------------------------
 * ストリームURL（チャンネルの再生リンク）を中/右クリックしたときに
 * 指定したメディアプレイヤーで再生します。また、登録したURLを
 * 中/右クリックしたときに2chブラウザなど指定したソフトで開きます。
 * Alt/Ctrl/Shiftキーを押しながらリンクを右クリックすると、通常通り
 * コンテキストメニューが表示されます。
 * ------------------------------------------------------------------
 * オリジナル：launch2chBrowser.uc.js
 * http://firefox.geckodev.org/?cmd=attach&pcmd=upload&page=userChrome.js
 */

function ucjs_rewrite_handleLinkClick(event, href, linkNode) {
	
	/* ■■ 設定ここから ■■ */
	// PeerCastで使用しているポートを指定。
	const sPort = "7144";
	
	// チャンネルを再生するメディアプレイヤーのパスを指定。「\」は「\\」に置き換える。
	const sPlayerPath = "C:\\Program Files\\pcyp\\pcwmp\\pcwmp.exe";
	
	// 2chブラウザのパスを指定。「\」は「\\」に置き換える。
	const sBrowserPath = "C:\\Program Files\\Jane\\Jane2ch.exe";
	
	// 2chブラウザで開くURLの一部を指定。
	const aURL = [
		"2ch.net",
		"60.kg",
		"jbbs.livedoor.jp",
		"kakiko.com"
	];
	/* ■■ 設定ここまで ■■ */
	
	if(href.match("http://localhost:" + sPort + "/pls/", "i")) {
		ucjsExecute(sPlayerPath, href);
	} else {
		for(var i=0; i<aURL.length; i++) {
			if(href.match(aURL[i], "i")) {
				ucjsExecute(sBrowserPath, href);
				break;
			}
		}
		if(i == aURL.length) ucjs_old_handleLinkClick(event, href, linkNode);
	}
}

var ucjsExecute = function(aFilePath, aArgs) {
	if(! ucjs_pclh_bKey) {
		var localFile = this.ucjsExecuteGetLocalFile(aFilePath);
		if(! localFile) return false;
		var argArray = new Array();
		if(aArgs) argArray = aArgs.toString().split(" ");
		var process = Components.classes['@mozilla.org/process/util;1'].getService(Components.interfaces.nsIProcess);
		try {
			process.init(localFile);
			process.run(false, argArray, argArray.length);
		} catch(e) {
			return false;
		}
		return true;
	}
}

var ucjsExecuteGetLocalFile = function(aFilePath) {
	var localFile = Components.classes['@mozilla.org/file/local;1'].createInstance(Components.interfaces.nsILocalFile);
	try {
		localFile.initWithPath(aFilePath);
		return localFile;
	} catch(e) {}
	return null;
}

var ucjs_old_handleLinkClick = handleLinkClick;
handleLinkClick = ucjs_rewrite_handleLinkClick;
var ucjs_pclh_bKey = false;

var ucjs_pclh_Key = function(e) {
	var ctrl = typeof e.modifiers == 'undefined' ? e.ctrlKey : e.modifiers & Event.CONTROL_MASK; 
	var shift = typeof e.modifiers == 'undefined' ? e.shiftKey : e.modifiers & Event.SHIFT_MASK;
	var alt = typeof e.modifiers == 'undefined' ? e.altKey : e.modifiers & Event.ALT_MASK;
	ucjs_pclh_bKey = (ctrl || shift || alt) ? true : false;
}

gBrowser.mPanelContainer.addEventListener("keydown", ucjs_pclh_Key, false);
gBrowser.mPanelContainer.addEventListener("keyup", ucjs_pclh_Key, false);
window.addEventListener("unload", function() {
	gBrowser.mPanelContainer.removeEventListener("keydown", ucjs_pclh_Key, false);
	gBrowser.mPanelContainer.removeEventListener("keyup", ucjs_pclh_Key, false);
}, false);